@@ -155,6 +155,8 @@ gail_button_object_init (GailButton      *button)
   button->press_description = NULL;
   button->release_description = NULL;
   button->click_keybinding = NULL;
+  button->action_queue = NULL;
+  button->action_idle_handler = 0;
 }
 
 AtkObject* 
@@ -303,15 +305,19 @@ gail_button_do_action (AtkAction *action,
     return FALSE;
 
   button = GAIL_BUTTON (action); 
-  if (button->action_idle_handler)
-    return FALSE;
+
   switch (i)
     {
     case 0:
     case 1:
     case 2:
-      button->action_number = i;
-      button->action_idle_handler = gtk_idle_add (idle_do_action, button);
+      if (!button->action_queue) 
+	{
+	  button->action_queue = g_queue_new ();
+	}
+      g_queue_push_head (button->action_queue, (gpointer) i);
+      if (!button->action_idle_handler)
+	button->action_idle_handler = gtk_idle_add (idle_do_action, button);
       break;
     default:
       return_value = FALSE;
@@ -341,39 +347,43 @@ idle_do_action (gpointer data)
     return FALSE;
 
   button = GTK_BUTTON (widget); 
-  switch (gail_button->action_number)
+  while (!g_queue_is_empty (gail_button->action_queue)) 
     {
-    case 0:
-      gtk_widget_activate (widget);
-      break;
-    case 1:
-      {
-        GdkEvent tmp_event;
-
-        button->in_button = TRUE;
-        gtk_button_enter (button);
-        /*
-         * Simulate a button press event. calling gtk_button_pressed() does
-         * not get the job done for a GtkOptionMenu.  
-         */
-        tmp_event.button.type = GDK_BUTTON_PRESS;
-        tmp_event.button.window = widget->window;
-        tmp_event.button.button = 1;
-        tmp_event.button.send_event = TRUE;
-        tmp_event.button.time = GDK_CURRENT_TIME;
-        tmp_event.button.axes = NULL;
-
-        gtk_widget_event (widget, &tmp_event);
-        break;
-      }
-    case 2:
-      button->in_button = FALSE;
-      gtk_button_leave (button);
-      gtk_button_released (button);
-      break;
-    default:
-      g_assert_not_reached ();
-      break;
+      gint action_number = (gint) g_queue_pop_head (gail_button->action_queue);
+      switch (action_number)
+	{
+	case 0:
+	  gtk_widget_activate (widget);
+	  break;
+	case 1:
+	  {
+	    GdkEvent tmp_event;
+	    
+	    button->in_button = TRUE;
+	    gtk_button_enter (button);
+	    /*
+	     * Simulate a button press event. calling gtk_button_pressed() does
+	     * not get the job done for a GtkOptionMenu.  
+	     */
+	    tmp_event.button.type = GDK_BUTTON_PRESS;
+	    tmp_event.button.window = widget->window;
+	    tmp_event.button.button = 1;
+	    tmp_event.button.send_event = TRUE;
+	    tmp_event.button.time = GDK_CURRENT_TIME;
+	    tmp_event.button.axes = NULL;
+	    
+	    gtk_widget_event (widget, &tmp_event);
+	    break;
+	  }
+	case 2:
+	  button->in_button = FALSE;
+	  gtk_button_leave (button);
+	  gtk_button_released (button);
+	  break;
+	default:
+	  g_assert_not_reached ();
+	  break;
+	}
     }
   return FALSE; 
 }
@@ -779,7 +789,10 @@ gail_button_finalize (GObject            *object)
       gtk_idle_remove (button->action_idle_handler);
       button->action_idle_handler = 0;
     }
-
+  if (button->action_queue)
+    {
+      g_queue_free (button->action_queue);
+    }
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
