@@ -49,6 +49,8 @@ struct _GailNotebook
    */
   GList*       page_cache;
   gint         selected_page;
+  gint         focus_tab_page;
+  guint        idle_focus_id;
 };
 
 GType gail_notebook_get_type (void);
